@@ -3,13 +3,14 @@
 from __future__ import annotations
 
 import datetime
+import enum
 import json
 import logging
 from collections.abc import AsyncIterator, Awaitable, Callable
-from typing import Any, List, Optional
+from typing import Any, List, Optional, cast
 from urllib.request import pathname2url
 
-from pydantic import BaseModel, Field, root_validator
+from pydantic import BaseModel, Field, root_validator, validator
 
 from .auth import AbstractAuth
 from .const import ITEMS
@@ -23,7 +24,9 @@ EVENT_PAGE_SIZE = 100
 # pylint: disable=line-too-long
 EVENT_API_FIELDS = f"kind,nextPageToken,nextSyncToken,items({EVENT_FIELDS})"
 
+CALENDAR_ID = "calendarId"
 CALENDAR_LIST_URL = "users/me/calendarList"
+CALENDAR_GET_URL = "calendars/{calendar_id}"
 CALENDAR_EVENTS_URL = "calendars/{calendar_id}/events"
 
 
@@ -76,10 +79,25 @@ class ListEventsRequest(SyncableRequest):
     """Api request to list events."""
 
     calendar_id: str = Field(alias="calendarId")
-    start_time: datetime.datetime = Field(default=None, alias="timeMin")
+    start_time: Optional[datetime.datetime] = Field(default=None, alias="timeMin")
     end_time: Optional[datetime.datetime] = Field(default=None, alias="timeMax")
     search: Optional[str] = Field(default=None, alias="q")
 
+    def to_request(self) -> _RawListEventsRequest:
+        """Convert to the raw API request for sending to the API."""
+        return _RawListEventsRequest(
+            **json.loads(self.json(exclude_none=True, by_alias=True)),
+            single_events=Boolean.TRUE,
+            order_by=OrderBy.START_TIME,
+        )
+
+    @validator("start_time", always=True)
+    def default_start_time(cls, value: datetime.datetime | None) -> datetime.datetime:
+        """Select a default start time value of not specified."""
+        if value is None:
+            return now()
+        return value
+
     @root_validator
     def check_datetime(cls, values: dict[str, Any]) -> dict[str, Any]:
         """Validate the date or datetime fields are set properly."""
@@ -91,6 +109,88 @@ class ListEventsRequest(SyncableRequest):
         allow_population_by_field_name = True
 
 
+class SyncEventsRequest(ListEventsRequest):
+    """Api request to list events when used in the context of sync."""
+
+    def to_request(self) -> _RawListEventsRequest:
+        """Disables default value behavior."""
+        request = _RawListEventsRequest(
+            **json.loads(self.json(exclude_none=True, by_alias=True))
+        )
+        if not request.sync_token:
+            request.single_events = Boolean.TRUE
+        return request
+
+    @validator("start_time", always=True)
+    def default_start_time(cls, value: datetime.datetime) -> datetime.datetime:
+        """Disables default value behavior."""
+        return value
+
+
+class OrderBy(str, enum.Enum):
+    """Represents the order of events returned."""
+
+    START_TIME = "startTime"
+    UPDATED = "updated"
+
+
+class Boolean(str, enum.Enum):
+    "Hack to support custom json encoding in pydantic." ""
+
+    TRUE = "true"
+    FALSE = "false"
+
+
+class _RawListEventsRequest(BaseModel):
+    """Api request to list events."""
+
+    calendar_id: str = Field(alias="calendarId")
+    max_results: int = Field(default=EVENT_PAGE_SIZE, alias="maxResults")
+    single_events: Optional[Boolean] = Field(alias="singleEvents")
+    order_by: Optional[OrderBy] = Field(alias="orderBy")
+    fields: str = Field(default=EVENT_API_FIELDS)
+    page_token: Optional[str] = Field(default=None, alias="pageToken")
+    sync_token: Optional[str] = Field(default=None, alias="syncToken")
+    start_time: Optional[datetime.datetime] = Field(default=None, alias="timeMin")
+    end_time: Optional[datetime.datetime] = Field(default=None, alias="timeMax")
+    search: Optional[str] = Field(default=None, alias="q")
+
+    def as_dict(self) -> dict[str, Any]:
+        """Return the object as a json dict."""
+        return cast(
+            dict[str, Any],
+            json.loads(
+                self.json(exclude_none=True, by_alias=True, exclude={"calendar_id"})
+            ),
+        )
+
+    @root_validator
+    def check_datetime(cls, values: dict[str, Any]) -> dict[str, Any]:
+        """Validate the date or datetime fields are set properly."""
+        return _validate_datetimes(values)
+
+    @root_validator
+    def check_sync_token_fields(cls, values: dict[str, Any]) -> dict[str, Any]:
+        """Validate the set of fields present when using a sync token."""
+        if not values.get("sync_token"):
+            return values
+        if (
+            values.get("order_by")
+            or values.get("search")
+            or values.get("time_min")
+            or values.get("time_max")
+        ):
+            raise ValueError(
+                f"Specified request params not compatible with sync_token: {values}"
+            )
+        return values
+
+    class Config:
+        """Model configuration."""
+
+        allow_population_by_field_name = True
+
+
 class _ListEventsResponseModel(SyncableResponse):
     """Api response containing a list of events."""
 
@@ -153,10 +253,16 @@ class GoogleCalendarService:
         params = {}
         if request:
             params = json.loads(request.json(exclude_none=True, by_alias=True))
-        _LOGGER.debug(params)
         result = await self._auth.get_json(CALENDAR_LIST_URL, params=params)
         return CalendarListResponse.parse_obj(result)
 
+    async def async_get_calendar(self, calendar_id: str) -> Calendar:
+        """Return the calendar with the specified id."""
+        result = await self._auth.get_json(
+            CALENDAR_GET_URL.format(calendar_id=calendar_id)
+        )
+        return Calendar.parse_obj(result)
+
     async def async_create_event(
         self,
         calendar_id: str,
@@ -190,19 +296,7 @@ class GoogleCalendarService:
         request: ListEventsRequest,
     ) -> _ListEventsResponseModel:
         """Return the list of events."""
-        params = {
-            "maxResults": EVENT_PAGE_SIZE,
-            "singleEvents": "true",
-            "orderBy": "startTime",
-            "fields": EVENT_API_FIELDS,
-        }
-        if not request.start_time and not request.sync_token:
-            request.start_time = now()
-        params.update(
-            json.loads(
-                request.json(exclude_none=True, by_alias=True, exclude={"calendar_id"})
-            )
-        )
+        params = request.to_request().as_dict()
         result = await self._auth.get_json(
             CALENDAR_EVENTS_URL.format(calendar_id=pathname2url(request.calendar_id)),
             params=params,
