@@ -9,11 +9,12 @@ from typing import Any, List, Mapping, Optional
 import aiohttp
 from aiohttp.client_exceptions import ClientError, ClientResponseError
 
-from .exceptions import ApiException, AuthException
+from .exceptions import ApiException, AuthException, InvalidSyncTokenException
 
 _LOGGER = logging.getLogger(__name__)
 
 HTTP_UNAUTHORIZED = 401
+HTTP_GONE = 410
 AUTHORIZATION_HEADER = "Authorization"
 ERROR = "error"
 STATUS = "status"
@@ -45,7 +46,7 @@ class AbstractAuth(ABC):  # pylint: disable=too-few-public-methods
         headers = {AUTHORIZATION_HEADER: f"Bearer {access_token}"}
         if not (url.startswith("http://") or url.startswith("https://")):
             url = f"{self._host}/{url}"
-        _LOGGER.debug("request[%s]=%s", method, url)
+        _LOGGER.debug("request[%s]=%s %s", method, url, kwargs.get("params"))
         if method == "post" and "json" in kwargs:
             _LOGGER.debug("request[post json]=%s", kwargs["json"])
         return await self._websession.request(method, url, **kwargs, headers=headers)
@@ -103,6 +104,10 @@ class AbstractAuth(ABC):  # pylint: disable=too-few-public-methods
         except ClientResponseError as err:
             if err.status == HTTP_UNAUTHORIZED:
                 raise AuthException(f"Unable to authenticate with API: {err}") from err
+            if err.status == HTTP_GONE:
+                raise InvalidSyncTokenException(
+                    "Sync token invalidated by server"
+                ) from err
             detail.append(err.message)
             raise ApiException(": ".join(detail)) from err
         except ClientError as err:
