@@ -23,16 +23,16 @@ class Calendar(BaseModel):
     summary: str = ""
     description: Optional[str]
     location: Optional[str]
-    timezone: Optional[str]
+    timezone: Optional[str] = Field(alias="timeZone", default=None)
 
 
 class DateOrDatetime(BaseModel):
     """A date or datetime."""
 
-    date: Optional[datetime.date]
-    date_time: Optional[datetime.datetime] = Field(alias="dateTime")
+    date: Optional[datetime.date] = Field(default=None)
+    date_time: Optional[datetime.datetime] = Field(alias="dateTime", default=None)
     # Note: timezone is only used for creating new events
-    timezone: Optional[str] = Field(alias="timeZone")
+    timezone: Optional[str] = Field(alias="timeZone", default=None)
 
     @property
     def value(self) -> Union[datetime.date, datetime.datetime]:
@@ -115,6 +115,7 @@ class Event(BaseModel):
     """A single event on a calendar."""
 
     id: Optional[str] = None
+    ical_uuid: Optional[str] = Field(alias="iCalUID", default=None)
     summary: str = ""
     start: DateOrDatetime
     end: DateOrDatetime
@@ -128,7 +129,12 @@ class Event(BaseModel):
     event_type: EventTypeEnum = Field(alias="eventType", default=EventTypeEnum.DEFAULT)
     visibility: VisibilityEnum = VisibilityEnum.DEFAULT
     attendees: list[Attendee] = []
-    attendeesOmitted: bool = False
+    attendees_omitted: bool = Field(alias="attendeesOmitted", default=False)
+    recurrence: list[str] = []
+    recurring_event_id: Optional[str] = Field(alias="recurringEventId", default=None)
+    original_start_time: Optional[DateOrDatetime] = Field(
+        alias="originalStartTime", default=None
+    )
 
     @root_validator(pre=True)
     def allow_cancelled_events(cls, values: dict[str, Any]) -> dict[str, Any]:
